@@ -37,7 +37,7 @@ using std::map;
 #include "hfst-ol.h"
 #include "ZHfstOspeller.h"
 
-namespace hfst_ol
+namespace hfst_ospell
   {
 
 #if HAVE_LIBARCHIVE
@@ -135,17 +135,13 @@ ZHfstOspeller::~ZHfstOspeller()
         current_sugger_ = 0;
         current_speller_ = 0;
       }
-    for (map<string, Transducer*>::iterator acceptor = acceptors_.begin();
-         acceptor != acceptors_.end();
-         ++acceptor)
+    for (auto& acceptor : acceptors_)
       {
-        delete acceptor->second;
+        delete acceptor.second;
       }
-    for (map<string, Transducer*>::iterator errmodel = errmodels_.begin();
-         errmodel != errmodels_.end();
-         ++errmodel)
+    for (auto& errmodel : errmodels_)
       {
-        delete errmodel->second;
+        delete errmodel.second;
       }
     can_spell_ = false;
     can_correct_ = false;
@@ -232,6 +228,23 @@ ZHfstOspeller::analyse(const string& wordform, bool ask_sugger)
     return rv;
   }
 
+AnalysisSymbolsQueue
+ZHfstOspeller::analyseSymbols(const string& wordform, bool ask_sugger)
+  {
+    AnalysisSymbolsQueue rv;
+    char* wf = strdup(wordform.c_str());
+    if ((can_analyse_) && (!ask_sugger) && (current_speller_ != 0))
+      {
+          rv = current_speller_->analyseSymbols(wf);
+      }
+    else if ((can_analyse_) && (ask_sugger) && (current_sugger_ != 0))
+      {
+          rv = current_sugger_->analyseSymbols(wf);
+      }
+    free(wf);
+    return rv;
+  }
+
 AnalysisCorrectionQueue
 ZHfstOspeller::suggest_analyses(const string& wordform)
   {
@@ -462,4 +475,4 @@ ZHfstOspeller::metadata_dump() const
     return metadata_.debug_dump();
 
   }
-} // namespace hfst_ol
+} // namespace hfst_ospell
