@@ -35,6 +35,7 @@
 #include <vector>
 #include <string>
 #include <algorithm>
+#include <unordered_set>
 #include <map>
 #include <sstream>
 #include <stdexcept>
@@ -51,8 +52,8 @@
 
 #include "ZHfstOspeller.h"
 
-using hfst_ol::ZHfstOspeller;
-using hfst_ol::Transducer;
+using hfst_ospell::ZHfstOspeller;
+using hfst_ospell::Transducer;
 
 typedef std::map<UnicodeString,bool> valid_words_t;
 valid_words_t valid_words;
@@ -63,6 +64,7 @@ struct word_t {
 };
 std::vector<word_t> words(16);
 std::string buffer;
+std::unordered_set<std::string> outputs;
 UnicodeString ubuffer, uc_buffer;
 size_t cw;
 
@@ -71,10 +73,12 @@ bool uc_first = false;
 bool uc_all = true;
 
 bool find_alternatives(ZHfstOspeller& speller, size_t suggs) {
+	outputs.clear();
+
 	for (size_t k=1 ; k <= cw ; ++k) {
 		buffer.clear();
 		words[cw-k].buffer.toUTF8String(buffer);
-		hfst_ol::CorrectionQueue corrections = speller.suggest(buffer);
+		hfst_ospell::CorrectionQueue corrections = speller.suggest(buffer);
 
 		if (corrections.size() == 0) {
 			continue;
@@ -82,7 +86,7 @@ bool find_alternatives(ZHfstOspeller& speller, size_t suggs) {
 
 		std::cout << "&";
 		// Because speller.set_queue_limit() doesn't actually work, hard limit it here
-		for (size_t i=0, e=corrections.size() ; i<e && i<suggs ; ++i) {
+		for (size_t i=0, n=0, e=corrections.size() ; i<e && n<suggs ; ++i) {
 			std::cout << "\t";
 
 			buffer.clear();
@@ -106,7 +110,11 @@ bool find_alternatives(ZHfstOspeller& speller, size_t suggs) {
 				words[0].buffer.tempSubString(words[cw-k].start + words[cw-k].count).toUTF8String(buffer);
 			}
 
-			std::cout << buffer;
+			if (outputs.count(buffer) == 0) {
+				std::cout << buffer;
+				++n;
+			}
+			outputs.insert(buffer);
 			corrections.pop();
 		}
 		std::cout << std::endl;
@@ -277,15 +285,15 @@ int zhfst_spell(const char* zhfst_filename) {
 		speller.read_zhfst(zhfst_filename);
 		speller.set_time_cutoff(6.0);
 	}
-	catch (hfst_ol::ZHfstMetaDataParsingError zhmdpe) {
+	catch (hfst_ospell::ZHfstMetaDataParsingError zhmdpe) {
 		fprintf(stderr, "cannot finish reading zhfst archive %s:\n%s.\n", zhfst_filename, zhmdpe.what());
 		return EXIT_FAILURE;
 	}
-	catch (hfst_ol::ZHfstZipReadingError zhzre) {
+	catch (hfst_ospell::ZHfstZipReadingError zhzre) {
 		fprintf(stderr, "cannot read zhfst archive %s:\n%s.\n", zhfst_filename, zhzre.what());
 		return EXIT_FAILURE;
 	}
-	catch (hfst_ol::ZHfstXmlParsingError zhxpe) {
+	catch (hfst_ospell::ZHfstXmlParsingError zhxpe) {
 		fprintf(stderr, "Cannot finish reading index.xml from %s:\n%s.\n", zhfst_filename, zhxpe.what());
 		return EXIT_FAILURE;
 	}
