@@ -18,7 +18,7 @@
 
 #include "ospell.h"
 
-namespace hfst_ol {
+namespace hfst_ospell {
 
 int nByte_utf8(unsigned char c)
 {
@@ -260,7 +260,7 @@ void Speller::lexicon_consume(void)
         return;
     }
     SymbolNumber this_input;
-    if (mutator != NULL) {
+    if (mutator != NULL && mode != Check) {
         this_input = alphabet_translator[input[input_state]];
     } else {
         // To support zhfst spellers without error models, we allow
@@ -559,9 +559,8 @@ AnalysisQueue Transducer::lookup(char * line)
         
     }
     
-    std::map<std::string, Weight>::const_iterator it;
-    for (it = outputs.begin(); it != outputs.end(); ++it) {
-        analyses.push(StringWeightPair(it->first, it->second));
+    for (auto& it : outputs) {
+        analyses.push(StringWeightPair(it.first, it.second));
     }
     
     return analyses;
@@ -770,9 +769,47 @@ AnalysisQueue Speller::analyse(char * line, int nbest)
         lexicon_epsilons();
         lexicon_consume();
     }
-    std::map<std::string, Weight>::const_iterator it;
-    for (it = outputs.begin(); it != outputs.end(); ++it) {
-        analyses.push(StringWeightPair(it->first, it->second));
+
+    for (auto& it : outputs) {
+        analyses.push(StringWeightPair(it.first, it.second));
+    }
+    return analyses;
+}
+
+
+AnalysisSymbolsQueue Speller::analyseSymbols(char * line, int nbest)
+{
+    (void)nbest;
+    mode = Lookup;
+    if (!init_input(line)) {
+        return AnalysisSymbolsQueue();
+    }
+    std::map<std::vector<std::string>, Weight> outputs;
+    AnalysisSymbolsQueue analyses;
+    TreeNode start_node(FlagDiacriticState(get_state_size(), 0));
+    queue.assign(1, start_node);
+    while (queue.size() > 0) {
+        next_node = queue.back();
+        queue.pop_back();
+        // Final states
+        if (next_node.input_state == input.size() &&
+            lexicon->is_final(next_node.lexicon_state)) {
+            Weight weight = next_node.weight +
+                lexicon->final_weight(next_node.lexicon_state);
+            std::vector<std::string> output = symbolify(lexicon->get_key_table(),
+                                                        next_node.string);
+            /* if the result is novel or lower weighted than before, insert it */
+            if (outputs.count(output) == 0 ||
+                outputs[output] > weight) {
+                outputs[output] = weight;
+            }
+        }
+        lexicon_epsilons();
+        lexicon_consume();
+    }
+
+    for (auto& it : outputs) {
+        analyses.push(SymbolsWeightPair(it.first, it.second));
     }
     return analyses;
 }
@@ -861,26 +898,24 @@ CorrectionQueue Speller::correct(char * line, int nbest,
         } else {
             results = &cache[first_input].results_len_1;
         }
-        for(StringWeightVector::const_iterator it = results->begin();
+        for(auto& it : *results) {
               // First get the correct weight limit
-              it != results->end(); ++it) {
-                best_suggestion = std::min(best_suggestion, it->second);
+                best_suggestion = std::min(best_suggestion, it.second);
                 if (nbest > 0) {
-                    nbest_queue.push(it->second);
+                    nbest_queue.push(it.second);
                     if (nbest_queue.size() > nbest) {
                         nbest_queue.pop();
                     }
                 }
             }
         adjust_weight_limits(nbest, beam);
-        for(StringWeightVector::const_iterator it = results->begin();
+        for(auto& it : *results) {
               // Then collect the results
-              it != results->end(); ++it) {
-            if (it->second <= limit && (nbest == 0 || // we either don't have an nbest condition or
-                                        (it->second <= nbest_queue.get_highest() && // we're below the worst nbest weight and
+            if (it.second <= limit && (nbest == 0 || // we either don't have an nbest condition or
+                                        (it.second <= nbest_queue.get_highest() && // we're below the worst nbest weight and
                                          correction_queue.size() < nbest &&
                                          nbest_queue.size() > 0))) { // number of results
-                correction_queue.push(StringWeightPair(it->first, it->second));
+                correction_queue.push(StringWeightPair(it.first, it.second));
                 if (nbest != 0) {
                     nbest_queue.pop();
                 }
@@ -957,14 +992,14 @@ CorrectionQueue Speller::correct(char * line, int nbest,
         }
     }
     adjust_weight_limits(nbest, beam);
-    std::map<std::string, Weight>::iterator it;
-    for (it = corrections.begin(); it != corrections.end(); ++it) {
-        if (it->second <= limit && // we're not over our weight limit and
+
+    for (auto& it : corrections) {
+        if (it.second <= limit && // we're not over our weight limit and
             (nbest == 0 || // we either don't have an nbest condition or
-             (it->second <= nbest_queue.get_highest() && // we're below the worst nbest weight and
+             (it.second <= nbest_queue.get_highest() && // we're below the worst nbest weight and
               correction_queue.size() < nbest &&
               nbest_queue.size() > 0))) { // number of results
-            correction_queue.push(StringWeightPair(it->first, it->second));
+            correction_queue.push(StringWeightPair(it.first, it.second));
             if (nbest != 0) {
                 nbest_queue.pop();
             }
@@ -1056,10 +1091,21 @@ std::string stringify(KeyTable * key_table,
                       SymbolVector & symbol_vector)
 {
     std::string s;
-    for (SymbolVector::iterator it = symbol_vector.begin();
-         it != symbol_vector.end(); ++it) {
-        if (*it < key_table->size()) {
-            s.append(key_table->at(*it));
+    for (auto& it : symbol_vector) {
+        if (it < key_table->size()) {
+            s.append(key_table->at(it));
+        }
+    }
+    return s;
+}
+
+std::vector<std::string> symbolify(KeyTable * key_table,
+                                   SymbolVector & symbol_vector)
+{
+    std::vector<std::string> s;
+    for (auto& it : symbol_vector) {
+        if (it < key_table->size()) {
+            s.push_back(key_table->at(it));
         }
     }
     return s;
@@ -1105,7 +1151,7 @@ bool Speller::init_input(char * line)
 
     while (**inpointer != '\0') {
         oldpointer = *inpointer;
-        if (mutator != NULL) {
+        if (mutator != NULL && mode != Check) {
             k = mutator->get_encoder()->find_key(inpointer);
         } else {
             k = lexicon->get_encoder()->find_key(inpointer);
@@ -1154,7 +1200,7 @@ void Speller::add_symbol_to_alphabet_translator(SymbolNumber to_sym)
     alphabet_translator.push_back(to_sym);
 }
 
-} // namespace hfst_ol
+} // namespace hfst_ospell
   
 char*
 hfst_strndup(const char* s, size_t n)
@@ -1172,4 +1218,3 @@ hfst_strndup(const char* s, size_t n)
     rv[n] = '\0';
     return rv;
   }
-    
